
local LIB_IDENTIFIER, LIB_VERSION = "LibSeasonalEventManager", 01
if _G[LIB_IDENTIFIER] and _G[LIB_IDENTIFIER].version > LIB_VERSION then
	return
end

local lib = _G[LIB_IDENTIFIER]

--[[
	This lib is self running.
	Using it normally should only require registering the update callback.
	
	The callback returns ([bool]eventActive, [object]eventOject)
		eventActive (true or false)
		
		
	This lib checks for running events on load and, on daily reset. 
	then, if an event is active, creates the eventObject based on 1 of the 4 detectable events, 
	or default info to be updated later by quest or item loot.
		
	eventOject:GetIndex()
		Used mainly by the lib to get the event info or saving by the add-on to compare later.
	eventOject:GetType()
		Currently, eventType is none, unknown, tickets
	eventOject:GetRewardsBy()
		Loot, quest, target (Jubilee Cake)
	eventOject:GetMaxDailyRewards()
		Last known amount of special rewards. Number of tickets per day
	eventOject:IsSameEvent(eventIndex)
		Used in add-ons to see if it's the same event that was previously running
		if add-on is saving eventIndex
		
		
		
		---------------------------------------------------------------------------------
		
		For comparing events with quests.
		The questIds are converted to names on load. 
		then, on quest pickup, it compares the questNames if the event has not been identified.
		
		Since events can have quests in different zones, each zone's quests are added separately under it's zoneIndex
		['quests'] = {
			[zoneIndex] = {questId},
		},
		
		EVENTS_TO_INDEX_MAP
			Allows dynamically generate an index for all events to be used across loading for event lookup.
			EVENTS_TO_INDEX_MAP[eventIndex] = eventInfo
		
		ITEM_TO_INDEX_MAP
			Allows simplifying event lookup by itemId.
			ITEM_TO_INDEX_MAP[itemId] = eventIndex
		
		QUEST_TO_INDEX_MAP
			Allows simplifying event lookup by questName.
			QUEST_TO_INDEX_MAP[zoneIdex][questName] = eventIndex
		
		EVENTS_TO_INDEX_MAP[ ITEM_TO_INDEX_MAP[itemId] ]
		EVENTS_TO_INDEX_MAP[ QUEST_TO_INDEX_MAP[zoneIdex][questName] ]
]]

---------------------------------------------------------------------------
-- Locals
---------------------------------------------------------------------------

local l_TICKETS_MAX			= lib.constants.maxTickets

local l_EVENT_NONE			= lib.constants.currentEventNone
local l_EVENT_UNKNOWN		= lib.constants.currentEventUnknown

local l_EVENT_TYPE_NONE		= lib.constants.eventTypeNone
local l_EVENT_TYPE_UNKNOWN	= lib.constants.eventTypeUnknown
local l_EVENT_TYPE_TICKETS	= lib.constants.eventTypeTickets
local l_EVENT_TYPE_BG		= lib.constants.eventTypeBG

local l_REWARDS_BY_NONE		= lib.constants.rewardsByNone
local l_REWARDS_BY_UNKNOWN	= lib.constants.rewardsByUnknown
local l_REWARDS_BY_QUEST	= lib.constants.rewardsByQuest
local l_REWARDS_BY_LOOT		= lib.constants.rewardsByLoot
local l_REWARDS_BY_TARGET	= lib.constants.rewardsByTarget

local dayInSeconds			= lib.constants.dayInSeconds

local l_EmptyString 		= lib.constants.stringEmpty

local getString 			= lib.GetString

local battlegroundAtivities = lib.constants.battlegroundAtivities


local defaultEventInfo = {
	['index'] 		= l_EVENT_NONE,
	['eventType'] 	= l_EVENT_TYPE_NONE,
	['rewardsBy'] 	= l_REWARDS_BY_NONE,
}

local questTypes = {
	[QUEST_TYPE_NONE] = true,
	[QUEST_TYPE_GROUP] = true,
	[QUEST_TYPE_HOLIDAY_EVENT] = true,
}

local standardBatlegrounds = {
	[1] = true,		-- Group Random Battleground
	[2] = true,		-- Group Random Battleground
	[67] = true,	-- Solo Random Battleground
	[68] = true,	-- Solo Random Battleground
}

local battlegroundInfo
---------------------------------------------------------------------------
-- 
---------------------------------------------------------------------------
local function selectSubzone(zoneId, subzoneIndex)
	local normalizedX, normalizedZ = GetPOIMapInfo(GetZoneIndex(zoneId), subzoneIndex)
	if ProcessMapClick(normalizedX, normalizedZ) == SET_MAP_RESULT_MAP_CHANGED then
		CALLBACK_MANAGER:FireCallbacks("OnWorldMapChanged", true)
		return SET_MAP_RESULT_MAP_CHANGED
	end
end
local currentZoneIndex
local function isMapLocationVisible(zoneId, subzoneIndex, locIndex)
	if currentZoneIndex == nil then
		currentZoneIndex = GetCurrentMapZoneIndex()
	end
	local mapId = GetMapIdByZoneId(zoneId)
		-- make sure the map is currently displaying the correct zone
	if SetMapToMapId(mapId) == SET_MAP_RESULT_MAP_CHANGED then
		CALLBACK_MANAGER:FireCallbacks("OnWorldMapChanged")
		
		if subzoneIndex > 0 then
			if selectSubzone(zoneId, subzoneIndex) ~= SET_MAP_RESULT_MAP_CHANGED then
				return false
			end
		end
	end
	--	WORLD_MAP_MANAGER:SetMapById(GetMapIdByIndex(zoneIndex))
		
	--	local isVisible = IsMapLocationVisible(locIndex)
	
	-- Lets change the map back to the previously selected map or player's position
	jo_callLater(LIB_IDENTIFIER, function()
		if currentZoneIndex and SetMapToMapId(GetMapIdByZoneId(GetZoneId(currentZoneIndex))) == SET_MAP_RESULT_MAP_CHANGED then
			CALLBACK_MANAGER:FireCallbacks("OnWorldMapChanged")
		end
		currentZoneIndex = nil
	end, 100)
	--[[
	local playerZoneIndex = GetUnitZoneIndex("player")
	if currentZoneIndex ~= playerZoneIndex then
		currentZoneIndex = currentZoneIndex > 2 and currentZoneIndex or playerZoneIndex
	
	end
	]]
	
	return IsMapLocationVisible(locIndex)
end

local function doesEventHaveVisiblePin(locationInfo)
	return isMapLocationVisible(locationInfo.zoneId, locationInfo.subzoneIndex, locationInfo.locationIndex)
end

---------------------------------------------------------------------------
-- 
---------------------------------------------------------------------------
--[[
local function isItemForEvent(itemIds, lootItemId)
	for i, itemId in pairs(itemIds) do
		if itemId == lootItemId then
			return true
		end
	end
end

local function isQuestForEvent(quests, questName)
	local zoneQuests = quests[GetUnitZoneIndex('player')] or {}
	for k, qName in pairs(zoneQuests) do
		if qName == questName then
			return true
		end
	end
end

local function processQuestNames(quests)
	local _quests = {}
	for zoneIndex, questIds in pairs(quests) do
		local temp = {}
		for zoneId, questId in pairs(questIds) do
			table.insert(temp, GetQuestName(questId))
		end
		_quests[zoneIndex] = temp
	end
	return _quests
end

]]

---------------------------------------------------------------------------
-- lib
---------------------------------------------------------------------------
local svVersion = 1
local svDefaults = {
	eventData = {
		eventIndex = l_EVENT_NONE,
		eventType = l_EVENT_TYPE_NONE,
	}
}

function lib:Initialize()
	ZO_ACTIVITY_FINDER_ROOT_MANAGER:RegisterCallback("OnUpdateLocationData", function()
		battlegroundAtivities = ZO_ACTIVITY_FINDER_ROOT_MANAGER.locationSetsLookupData[LFG_ACTIVITY_BATTLE_GROUND_NON_CHAMPION]
		if self.initialized then
			self:Refresh()
		end
	end)
	
	local function OnLoaded(_, name)
		if name ~= LIB_IDENTIFIER then return end
		EVENT_MANAGER:UnregisterForEvent(LIB_IDENTIFIER, EVENT_ADD_ON_LOADED)
		
		self.savedVars = ZO_SavedVars:NewAccountWide('LibSesonalEventManager_SV_Data', svVersion, nil, svDefaults, GetWorldName(), "$AllAccounts")
		self.eventData = self.savedVars.eventData
	--	self:OnDeferredInitialize()
		
		self:SetActiveEventType(l_EVENT_TYPE_NONE)
		
		local function onPlayerActivated()
			EVENT_MANAGER:UnregisterForEvent(LIB_IDENTIFIER, EVENT_ADD_ON_LOADED)
		--	d( '|cFF00FF' .. LIB_IDENTIFIER '|r' .. " version: " .. LIB_VERSION)
		end
		EVENT_MANAGER:RegisterForEvent(LIB_IDENTIFIER, EVENT_PLAYER_ACTIVATED, onPlayerActivated)
	end
	EVENT_MANAGER:RegisterForEvent(LIB_IDENTIFIER, EVENT_ADD_ON_LOADED, OnLoaded)
end

---------------------------------------------------------------------------
-- 
---------------------------------------------------------------------------
function lib:RegisterEvents()
	local function onEventAnnouncementsUpdated(event)
	--	d( '--- ' .. event .. ' ---')
		-- refresh
	end
	-- I want to see if these will be usefull.
    EVENT_MANAGER:RegisterForEvent(LIB_IDENTIFIER, EVENT_MARKET_ANNOUNCEMENT_UPDATED, function() onEventAnnouncementsUpdated('EVENT_MARKET_ANNOUNCEMENT_UPDATED') end)
    EVENT_MANAGER:RegisterForEvent(LIB_IDENTIFIER, EVENT_EVENT_ANNOUNCEMENTS_UPDATED, function() onEventAnnouncementsUpdated('EVENT_EVENT_ANNOUNCEMENTS_UPDATED') end)
    EVENT_MANAGER:RegisterForEvent(LIB_IDENTIFIER, EVENT_EVENT_ANNOUNCEMENTS_RECEIVED, function() onEventAnnouncementsUpdated('EVENT_EVENT_ANNOUNCEMENTS_RECEIVED') end)
end

function lib:RegisterLookupEvents()
	local function onQuestAdded(eventId, questIndex, questName)
		local rewardDataList = SYSTEMS:GetObject(ZO_INTERACTION_SYSTEM_NAME):GetRewardData(questIndex)
		
		if #rewardDataList == 0 then return end
		-- We only need to refresh the interaction if event tickets are present.
		for i, data in ipairs(rewardDataList) do
			if data.rewardType == REWARD_TYPE_EVENT_TICKETS then
			
				if self:GetActiveEventIndex() == l_EVENT_UNKNOWN then
					local eventIndex = self:GetEventIndexByQuestName(questName)
					if eventIndex then
						self:UpdateActiveEventIndex(eventIndex)
					end
				end
				return 
			end
		end
	end
	EVENT_MANAGER:RegisterForEvent(LIB_IDENTIFIER, EVENT_QUEST_ADDED, onQuestAdded)
	
    local function onInventorySingleSlotUpdate(eventId, bagId, slotId, isNewItem, itemIdsoundCategory, updateReason, stackCountChange)
		if stackCountChange > 0 then
			if self:GetActiveEventIndex() > l_EVENT_UNKNOWN then
				local itemId = GetItemId(bagId, slotId)
				local eventIndex = self:GetEventIndexByItemId(itemId)
				if eventIndex then
					self:UpdateActiveEventIndex(eventIndex)
				end
			end
		end
    end
	EVENT_MANAGER:RegisterForEvent(LIB_IDENTIFIER, EVENT_INVENTORY_SINGLE_SLOT_UPDATE, onInventorySingleSlotUpdate)
end

function lib:UnregisterEvents()
	EVENT_MANAGER:UnregisterForEvent(LIB_IDENTIFIER, EVENT_MARKET_ANNOUNCEMENT_UPDATED)
	EVENT_MANAGER:UnregisterForEvent(LIB_IDENTIFIER, EVENT_EVENT_ANNOUNCEMENTS_UPDATED)
	EVENT_MANAGER:UnregisterForEvent(LIB_IDENTIFIER, EVENT_EVENT_ANNOUNCEMENTS_RECEIVED)
	self:UnregisterLookupEvents()
end

function lib:UnregisterLookupEvents()
	EVENT_MANAGER:UnregisterForEvent(LIB_IDENTIFIER, EVENT_QUEST_ADDED)
	EVENT_MANAGER:UnregisterForEvent(LIB_IDENTIFIER, EVENT_INVENTORY_SINGLE_SLOT_UPDATE)
end

---------------------------------------------------------------------------
-- 
---------------------------------------------------------------------------
function lib:RegisterOnDailyReset()
	EVENT_MANAGER:UnregisterForUpdate(self.name .. '_OnUpdate')
	
	local secondsRemaining = self.GetDailyResetTimeRemainingSeconds()
	if secondsRemaining <= 0 then
		zo_callLater(function()
			self:RegisterOnDailyReset()
		end, 100)
		return
	end
	
	local function onUpdate()
		if self.isUpdating then
			-- In the case UpdateEventData was called by another function, we will run onUpdate again.
			-- It can overwrite changes made if UpdateEventData was called with a new eventIndex.
			zo_callLater(onUpdate, 100)
			return
		end
		self:Refresh()
	end
	EVENT_MANAGER:RegisterForUpdate(self.name .. '_OnUpdate', (secondsRemaining * 1000), onUpdate)
end

---------------------------------------------------------------------------
-- 
---------------------------------------------------------------------------
function lib:GetImpresarioFromMap()
	local zoneId = 3
	local subzoneIndex = 0
	local locIndex = 5
	
	return isMapLocationVisible(zoneId, subzoneIndex, locIndex)
end

function lib:GetActiveBattlegound()
--	for _, activityType in pairs({LFG_ACTIVITY_BATTLE_GROUND_CHAMPION, LFG_ACTIVITY_BATTLE_GROUND_NON_CHAMPION, LFG_ACTIVITY_BATTLE_GROUND_LOW_LEVEL}) do
	--	for id, location in pairs(ZO_ACTIVITY_FINDER_ROOT_MANAGER.locationSetsLookupData[activityType]) do
		for id, location in pairs(battlegroundAtivities) do
			if not standardBatlegrounds[id] then
				if location.isActive and location.maxGroupSize == 4 then
					battlegroundInfo = location
					return id
				end
			end
		end
--	end
end

function lib:CheckForAndGetActiveEventType()
	if self:GetImpresarioFromMap() then
		return l_EVENT_TYPE_TICKETS
	elseif self:GetActiveBattlegound() ~= nil then
		return l_EVENT_TYPE_BG
	end
	
	return l_EVENT_TYPE_NONE
end

function lib:CheckForActiveEvent()
	local activeType = self:CheckForAndGetActiveEventType()
	local eventIndex
	
	if self:HasEventExpired() then
		self:SetActiveEventType(activeType)
		if activeType == l_EVENT_TYPE_BG then
			eventIndex = self.indexToBattlegroundIdMap[battlegroundInfo.id]
		elseif activeType == l_EVENT_TYPE_TICKETS then
			eventIndex = self:GetEventIndexByVisibleLocation()
		end
	end
	
	if eventIndex and self:IsNewEvent(eventIndex) then
		self.eventData.eventIndex = eventIndex
	end
	
	return activeType ~= l_EVENT_TYPE_NONE
end

function lib:Activate()
	self:ResetToSavedEvent()
	if self:GetActiveEventIndex() == l_EVENT_UNKNOWN then
		if self.eventData.eventType == l_EVENT_TYPE_BG then
		else
			for questIndex = 1, GetNumJournalQuests() do
				local questName, _, _, _, _, _, _, _, _, questType = GetJournalQuestInfo(questIndex)
				if questTypes[questType] then
					local eventIndex = self:GetEventIndexByQuestName(questName)
					if eventIndex then
						self:UpdateActiveEventIndex(eventIndex)
						return
					end
				end
			end
		end
	end
end

function lib:Deactivate()
	self:SetActiveEventType(l_EVENT_TYPE_NONE)
	self.eventData.eventIndex = l_EVENT_NONE
	
	self.currentEvent = self.defaultEvent
	self:UnregisterEvents()
end

function lib:Refresh()
	if self.isUpdating then return end
	self.isUpdating = true
	
	local isEventActive = self:CheckForActiveEvent()
	if isEventActive then
		if not self.active then
			-- activate
			self:Activate()
		end
		self:UpdateActiveEventIndex(self.eventData.eventIndex)
	elseif self.active then
		-- deactivate
		self:Deactivate()
	end
	self.active = isEventActive
	
	self:UpdateResetTime()

	CALLBACK_MANAGER:FireCallbacks('On_Seasonal_Event_Updated', isEventActive, self.currentEvent)
	
	self:RegisterOnDailyReset()
	self.isUpdating = false
end

function lib:HasEventExpired(eventType)
	-- If 2 days cycles have past since it was last updated.
	if self.eventData.eventIndex == l_EVENT_NONE then
		return true
	end
	
	if self.eventData.eventType ~= eventType then
--		return true
	end
	local resetTime = self.eventData.resetTime or 0
	return (resetTime + dayInSeconds) < GetTimeStamp()

--	return self.eventData.resetTime < GetTimeStamp()
end

function lib:UpdateResetTime()
	local resetTime = self.actieve and self.GetDailyResetTimeRemainingSeconds() + GetTimeStamp() or 0
	self.eventData.resetTime = resetTime
end

function lib:IsNewEvent(eventIndex)
	return self:GetActiveEventIndex() ~= eventIndex
end

---------------------------------------------------------------------------
-- 
---------------------------------------------------------------------------
function lib:ResetToSavedEvent()
	local eventIndex = self.eventData.eventIndex
	local resetTime = self.eventData.resetTime or 0
	
	local locIndex = self:GetEventIndexByVisibleLocation()
	if locIndex ~= l_EVENT_NONE and locIndex ~= eventIndex then
		eventIndex = locIndex
	end
	
	if eventIndex then
		self:UpdateActiveEventIndex(eventIndex)
	end
end

function lib:SetActiveEventType(eventType)
	self.eventData.eventType = eventType
end

function lib:UpdateActiveEvent(eventIndex)
	local eventInfo = self:GetEventInfoByIndex(eventIndex)
	
	if eventInfo ~= nil then
		local newEvent = self.event_class:New(eventInfo)
		self.currentEvent = newEvent
		
		if self.currentEvent:GetType() == l_EVENT_TYPE_UNKNOWN then
			self.currentEvent:SetEventType(self:GetActiveEventType())
		else
			self:SetActiveEventType(eventInfo.eventType)
		end

		if not self.isUpdating then
			CALLBACK_MANAGER:FireCallbacks('On_Seasonal_Event_Updated', true, self.currentEvent)
		end
	end
	
	-- Need to set up event if the event was not detected.
	if self:GetActiveEventIndex() > l_EVENT_UNKNOWN then
		self:UnregisterLookupEvents()
	else
		self:RegisterLookupEvents()
	end
end

function lib:UpdateActiveEventIndex(eventIndex)
	if eventIndex == l_EVENT_NONE then
		eventIndex = self:GetEventIndexByVisibleLocation()
	end
	
	if self:IsNewEvent(eventIndex) then
		self.eventData.eventIndex = eventIndex
		self:UpdateActiveEvent(eventIndex)
	end
end

---------------------------------------------------------------------------
-- Event info parsing
---------------------------------------------------------------------------
function lib:GetEventInfoByIndex(eventIndex)
	return self.eventsToIndexMap[eventIndex]
end

function lib:GetEventIndexByQuestName(questName)
	return self.indexToQuestNameMap[questName]
end

function lib:GetEventIndexByItemId(itemId)
	return self.indexToItemIdMap[itemId]
end

function lib:GetEventIndexByBattleGroundId(bgId)
	return self.indexToBattlegroundIdMap[bgId]
end

function lib:GetEventIndexByVisibleLocation()
	for eventIndex, location in pairs(self.locationToIndexMap) do
		if doesEventHaveVisiblePin(location) then
			return eventIndex
		end
	end

	return l_EVENT_TYPE_UNKNOWN
end

---------------------------------------------------------------------------
-- Deferred initialization
---------------------------------------------------------------------------
-- Mapping the event data allows for simplifying lookup.
do
	local function mapIndexByKey(self, key, eventIndex, source, indexFunc)
		for k, v in pairs(source) do
			self[key][indexFunc(v)] = eventIndex
		end
	end
	
	local function mapIndexToQuestName(self, eventIndex, quests)
		mapIndexByKey(self, 'indexToQuestNameMap', eventIndex, quests, function(questId) return GetQuestName(questId) end)
	end
	local function mapIndexToItemId(self, eventIndex, items)
		mapIndexByKey(self, 'indexToItemIdMap', eventIndex, items, function(itemId) return itemId end)
	end
	local function mapIndexToTargetName(self, eventIndex, targets)
		mapIndexByKey(self, 'indexToTargetNameMap', eventIndex, targets, function(target) return getString(target) end)
	end
	local function mapIndexToBattlegroundId(self, eventIndex, battlegrounds)
		mapIndexByKey(self, 'indexToBattlegroundIdMap', eventIndex, battlegrounds, function(bgId) return bgId end)
	end

	local function mapLocationToIndex(self, eventIndex, location)
		self.locationToIndexMap[eventIndex] = location
	end
	
	function lib:MapEventInfo()
		local eventsToIndexMap = self.eventsToIndexMap
		
		for _, eventInfo in ipairs(self.events) do
			table.insert(eventsToIndexMap, eventInfo)
			eventInfo.index = #eventsToIndexMap
			
			if eventInfo.quests then
				mapIndexToQuestName(self, eventInfo.index, eventInfo.quests)
			end
			if eventInfo.items then
				mapIndexToItemId(self, eventInfo.index, eventInfo.items)
			end
			if eventInfo.targets then
				mapIndexToTargetName(self, eventInfo.index, eventInfo.targets)
			end
			if eventInfo.location then
				mapLocationToIndex(self, eventInfo.index, eventInfo.location)
			end
			if eventInfo.battlegrounds then
				mapIndexToBattlegroundId(self, eventInfo.index, eventInfo.battlegrounds)
			end
		end

		self.eventsToIndexMap = eventsToIndexMap
	end
end

function lib:RegisterStrings()
	-- Dynamically generate string ids and register strings
	local strings = {}

	for i, _string in ipairs(self.strings.titles) do
		strings['SI_LIB_EVENTS_MANAGER_TITLE' .. i] = _string
	end
	for i, _string in ipairs(self.strings.descriptions) do
		strings['SI_LIB_EVENTS_MANAGER_DESCRIPTION' .. i] = _string
	end
	
	battlegroundAtivities = ZO_ACTIVITY_FINDER_ROOT_MANAGER.locationSetsLookupData[LFG_ACTIVITY_BATTLE_GROUND_NON_CHAMPION]
	for i, event in pairs(self.events) do
		if event.battlegroundId then
			local battleground = battlegroundAtivities[event.battlegroundId]
			strings['SI_LIB_EVENTS_MANAGER_TITLE' .. i] = battleground.rawName
			strings['SI_LIB_EVENTS_MANAGER_DESCRIPTION' .. i] = battleground.description
		end
	end
	
	for stringId, stringValue in pairs(strings) do
		ZO_CreateStringId(stringId, stringValue)
		SafeAddVersion(stringId, 1)
	end
end

function lib:OnDeferredInitialize()
	if self.initialized then return end
	
	self:RegisterStrings()
	self:MapEventInfo()
	self:Refresh()
	self.initialized = true
end

---------------------------------------------------------------------------
-- API
---------------------------------------------------------------------------
function lib.WouldTicketsExcedeMax(eventTickets)
	return ZO_SharedInteraction:WouldCurrencyExceedMax(REWARD_TYPE_EVENT_TICKETS, eventTickets)
end

function lib.GetDailyResetTimeRemainingSeconds()
	return GetTimeUntilNextDailyLoginRewardClaimS()
end

function lib:IsEventActive()
	return self.eventData.eventType ~= l_EVENT_TYPE_NONE
end

function lib:GetActiveEventIndex()
	if self.currentEvent then
		return self.currentEvent:GetIndex()
	end
	return l_EVENT_NONE
end

function lib:GetActiveEventType()
	return self.eventData.eventType or l_EVENT_TYPE_NONE
end

function lib:GetCurrentEvent()
	return self.currentEvent or defaultEvent
end

function lib:RegisterUpdateCallback(callback)
	self:OnDeferredInitialize()
	-- We want to fire the callback immediately so the addon gets updated without having to wait for event updates.
	if self.eventData then
		zo_callLater(function()
			callback(self.active, self:GetCurrentEvent())
		end, 500)
	end
	CALLBACK_MANAGER:RegisterCallback('On_Seasonal_Event_Updated', callback)
end

function lib:GetEventIndexByFilter(eventType)
	
end

---------------------------------------------------------------------------
-- currentEvent info
---------------------------------------------------------------------------
function lib:GetEventTitle()
	if self.currentEvent then
		return self.currentEvent:GetTitle()
	end
	return l_EmptyString
end

function lib:GetEventDescription()
	if self.currentEvent then
		return self.currentEvent:GetDescription()
	end
	return l_EmptyString
end

function lib:GetEventInfo()
	if self.currentEvent then
		return self.currentEvent:GetInfo()
	end
	return l_EmptyString, l_EmptyString
end

function lib:GetEventMaxDailyRewards()
	if self.currentEvent then
		return self.currentEvent:GetMaxDailyRewards()
	end
	return l_EVENT_NONE
end

function lib:IsImpresarioVisible()
	return self.impresario or false
end

---------------------------------------------------------------------------
-- 
---------------------------------------------------------------------------
IJA_Seasonal_Event_Manager = lib:New()

--[[
/script IJA_Seasonal_Event_Manager:TestBattlegound()
/script IJA_Seasonal_Event_Manager:Refresh()
IJA_Seasonal_Event_Manager.currentEvent.eventIndex 
--	/script d( IJA_Seasonal_Event_Manager:GetActiveBattlegound())
--	/script d( IJA_Seasonal_Event_Manager:UpdateActiveEventIndex(17))


BattlegroundDataTest = ZO_ACTIVITY_FINDER_ROOT_MANAGER.locationSetsLookupData[LFG_ACTIVITY_BATTLE_GROUND_NON_CHAMPION]
function lib:GetActiveBattlegound()
	local activeBattleground = 0
	
	for _, activityType in pairs({LFG_ACTIVITY_BATTLE_GROUND_CHAMPION,LFG_ACTIVITY_BATTLE_GROUND_NON_CHAMPION,LFG_ACTIVITY_BATTLE_GROUND_LOW_LEVEL}) do
		for i, location in pairs(ZO_ACTIVITY_FINDER_ROOT_MANAGER.locationSetsLookupData[activityType]) do
			if location.isActive then
				--activeBattleground = 
			end
			d( zo_strformat('Id: <<1>>, Name: <<2>>', location.id, location.description))
		end
	end
end
/script IJA_Seasonal_Event_Manager.savedVars = {}

/script d( IJA_Seasonal_Event_Manager:GetEventTitle())
/script d( IJA_Seasonal_Event_Manager:GetEventDescription())
/script d( IJA_Seasonal_Event_Manager:GetEventInfo())
/script d( IJA_Seasonal_Event_Manager:GetEventMaxDailyRewards())




        for questIndex = 1, GetNumJournalQuests() do
			local questName, _, _, _, _, _, _, _, _, questType = GetJournalQuestInfo(questIndex)
			if questType == then
				local eventIndex = self:GetEventIndexByQuestName(questName)
				if eventIndex then
					self:UpdateActiveEventIndex(eventIndex)
				end
			end
        end
		
function lib:TestBattlegound()
	local activeBattleground = 0
	
	for _, activityType in pairs({LFG_ACTIVITY_BATTLE_GROUND_CHAMPION,LFG_ACTIVITY_BATTLE_GROUND_NON_CHAMPION,LFG_ACTIVITY_BATTLE_GROUND_LOW_LEVEL}) do
		for i, location in pairs(ZO_ACTIVITY_FINDER_ROOT_MANAGER.locationSetsLookupData[activityType]) do
			if location.isActive then
			end
			local bgs = self.savedVars.bgs or {}
			bgs[location.id] = location
			self.savedVars.bgs = bgs
		--	d( zo_strformat('Id: <<1>>, Name: <<2>>', location.id, location.description))
		end
	end
end
-- activityType = 2 -- rnd normal
-- activityType = 3 -- rnd vet
-- activityType = 7 -- battleground
	
	SecurePostHook(ZO_ACTIVITY_FINDER_ROOT_MANAGER, 'SetLocationSelected', function(self, location, selected)
		if location.isSelected then
			d(location)
		end
	end)

	ZO_ACTIVITY_FINDER_ROOT_MANAGER:RegisterCallback("OnSelectionsChanged", function()
		if KEYBOARD_GROUP_MENU_SCENE:IsShowing() then
			local selectedNode = GROUP_MENU_KEYBOARD.navigationTree:GetSelectedNode()
			if selectedNode then
				local categoryFragment = selectedNode.data.categoryFragment
				if categoryFragment then
					if categoryFragment == DUNGEON_FINDER_KEYBOARD:GetFragment() then
						d( 'Is DUNGEON_FINDER_KEYBOARD')
					elseif categoryFragment == BATTLEGROUND_FINDER_KEYBOARD:GetFragment() then
						d( 'Is BATTLEGROUND_FINDER_KEYBOARD')
					end
				end
			end
		end
	end)
	
	local list = ZO_ACTIVITY_FINDER_ROOT_GAMEPAD:GetMainList()
    list:SetOnSelectedDataChangedCallback(function(_, selectedData)
		-- Here we reset selectedMode on every selection changed
		selectedMode = 0
	end)
	
	-- On selection "click" set selectedMode
	SecurePostHook(DUNGEON_FINDER_GAMEPAD, 'OnShowing', function()
		d( 'Is DUNGEON_FINDER_GAMEPAD')
		selectedMode = 1
	end)
	SecurePostHook(BATTLEGROUND_FINDER_GAMEPAD, 'OnShowing', function()
		d( 'Is BATTLEGROUND_FINDER_GAMEPAD')
		selectedMode = 2
	end)
]]

--[[ Example usage
local wouldTicketsExcedeMax = IJA_Seasonal_Event_Manager:WouldTicketsExcedeMax(eventTickets)


	local function onSeasonalEventUpdate(active, eventObject)
		if eventObject == nil then return end
		
		if eventObject:GetRewardsBy() > l_REWARDS_BY_NONE then
			if active then
				local lastEventIndex = self.savedVars.eventInfo.eventIndex
				if not eventObject:IsSameEvent(lastEventIndex) then
					-- start new event
					self:SetUpEvent(eventObject)
				else
					-- reset for dailies?
					self:ResetDailyInfo()
				end
				self:UpdateDailyIconTexture()
			end
			
			self:RefreshGamepadMenu()
			self:ChangeState(active)
		end
	end
	
	IJA_Seasonal_Event_Manager:RegisterUpdateCallback(onSeasonalEventUpdate)
]]


